@@ -28,6 +28,14 @@ bool setGSPackageAdditions( Calamares::GlobalStorage* gs,
                             const Calamares::ModuleSystem::InstanceKey& module,
                             const QVariantList& installPackages,
                             const QVariantList& tryInstallPackages );
+/** @brief Sets the install-packages GS keys for the given module
+ *
+ * This replaces previously-set install-packages lists. Use this with
+ * plain lists of package names. It does not support try-install.
+ */
+bool setGSPackageAdditions( Calamares::GlobalStorage* gs,
+                            const Calamares::ModuleSystem::InstanceKey& module,
+                            const QStringList& installPackages );
 // void setGSPackageRemovals( const Calamares::ModuleSystem::InstanceKey& key, const QVariantList& removePackages );
 }  // namespace Packages
 }  // namespace CalamaresUtils
