@@ -16,6 +16,7 @@
 
 #include <kpmcore/core/device.h>
 #include <kpmcore/core/partition.h>
+#include <kpmcore/core/partitiontable.h>
 
 namespace CalamaresUtils
 {
@@ -26,6 +27,19 @@ namespace Partition
 using ::Device;
 using ::Partition;
 
+const PartitionTable*
+getPartitionTable( const Partition* partition )
+{
+    const PartitionNode* root = partition;
+    while ( root && !root->isRoot() )
+    {
+        root = root->parent();
+    }
+
+    return dynamic_cast< const PartitionTable* >( root );
+}
+
+
 bool
 isPartitionFreeSpace( const Partition* partition )
 {
