@@ -15,6 +15,7 @@
 
 #include "DllMacro.h"
 
+#include <QList>
 #include <QString>
 #include <QVariantMap>
 
@@ -34,11 +35,17 @@ DLLEXPORT QString getString( const QVariantMap& map, const QString& key, const Q
 
 /** @brief Get a string list from a mapping with a given key; returns @p d if no value.
  *
- * This is slightly more lenient that getString(), and a single-string value will
+ * This is slightly more lenient than getString(), and a single-string value will
  * be returned as a 1-item list.
  */
 DLLEXPORT QStringList getStringList( const QVariantMap& map, const QString& key, const QStringList& d = QStringList() );
 
+/**
+ * Get a list from a mapping with a given key; returns @p d if no value.
+ */
+DLLEXPORT QList< QVariant >
+getList( const QVariantMap& map, const QString& key, const QList< QVariant >& d = QList< QVariant >() );
+
 /**
  * Get an integer value from a mapping with a given key; returns @p d if no value.
  */
