@@ -24,10 +24,13 @@
 #include "viewpages/BlankViewStep.h"
 #include "viewpages/ExecutionViewStep.h"
 #include "viewpages/ViewStep.h"
+#include "widgets/ErrorDialog.h"
+#include "widgets/TranslationFix.h"
 
 #include <QApplication>
 #include <QBoxLayout>
 #include <QClipboard>
+#include <QDialogButtonBox>
 #include <QFile>
 #include <QMessageBox>
 #include <QMetaObject>
@@ -82,6 +85,12 @@ ViewManager::ViewManager( QObject* parent )
     connect( JobQueue::instance(), &JobQueue::finished, this, &ViewManager::next );
 
     CALAMARES_RETRANSLATE_SLOT( &ViewManager::updateButtonLabels );
+
+#ifdef PRESERVE_FOR_TRANSLATION_PURPOSES
+    tr( "&Yes" );
+    tr( "&No" );
+    tr( "&Close" );
+#endif
 }
 
 
@@ -143,58 +152,32 @@ ViewManager::insertViewStep( int before, ViewStep* step )
 void
 ViewManager::onInstallationFailed( const QString& message, const QString& details )
 {
-    bool shouldOfferWebPaste = std::get< 0 >( Calamares::Branding::instance()->uploadServer() )
-            != Calamares::Branding::UploadServerType::None
-        and std::get< 2 >( Calamares::Branding::instance()->uploadServer() ) != 0;
-
     cError() << "Installation failed:" << message;
     cDebug() << Logger::SubEntry << "- message:" << message;
     cDebug() << Logger::SubEntry << "- details:" << Logger::NoQuote << details;
 
     QString heading
         = Calamares::Settings::instance()->isSetupMode() ? tr( "Setup Failed" ) : tr( "Installation Failed" );
-    QString pasteMsg = tr( "Would you like to paste the install log to the web?" );
-    QString text = "<p>" + message + "</p>";
-    if ( !details.isEmpty() )
-    {
-        text += "<p>"
-            + CalamaresUtils::truncateMultiLine( details, CalamaresUtils::LinesStartEnd { 6, 2 } )
-                  .replace( '\n', QStringLiteral( "<br/>" ) )
-            + "</p>";
-    }
-    if ( shouldOfferWebPaste )
-    {
-        text += "<p>" + pasteMsg + "</p>";
-    }
 
-    QMessageBox* msgBox = new QMessageBox();
-    msgBox->setIcon( QMessageBox::Critical );
-    msgBox->setWindowTitle( tr( "Error" ) );
-    msgBox->setText( "<strong>" + heading + "</strong>" );
-    msgBox->setInformativeText( text );
-    if ( shouldOfferWebPaste )
-    {
-        msgBox->setStandardButtons( QMessageBox::Yes | QMessageBox::No );
-        msgBox->setDefaultButton( QMessageBox::No );
-        msgBox->button( QMessageBox::Yes )->setText( tr( "&Yes" ) );
-        msgBox->button( QMessageBox::No )->setText( tr( "&No" ) );
-    }
-    else
-    {
-        msgBox->setStandardButtons( QMessageBox::Close );
-        msgBox->setDefaultButton( QMessageBox::Close );
-        msgBox->button( QMessageBox::Close )->setText( tr( "&Close" ) );
-    }
-    msgBox->show();
+    ErrorDialog* errorDialog = new ErrorDialog();
+    errorDialog->setWindowTitle( tr( "Error" ) );
+    errorDialog->setHeading( "<strong>" + heading + "</strong>" );
+    errorDialog->setInformativeText( message );
+    errorDialog->setShouldOfferWebPaste( Calamares::Branding::instance()->uploadServer() );
+    errorDialog->setDetails( details );
+    errorDialog->show();
 
     cDebug() << "Calamares will quit when the dialog closes.";
-    connect( msgBox, &QMessageBox::buttonClicked, [msgBox]( QAbstractButton* button ) {
-        if ( msgBox->buttonRole( button ) == QMessageBox::ButtonRole::YesRole )
-        {
-            CalamaresUtils::Paste::doLogUploadUI( msgBox );
-        }
-        QApplication::quit();
-    } );
+    connect( errorDialog,
+             &QDialog::finished,
+             [ errorDialog ]( int result )
+             {
+                 if ( result == QDialog::Accepted && errorDialog->shouldOfferWebPaste() )
+                 {
+                     CalamaresUtils::Paste::doLogUploadUI( errorDialog );
+                 }
+                 QApplication::quit();
+             } );
 }
 
 
@@ -516,8 +499,7 @@ ViewManager::confirmCancelInstallation()
                                                      "The installer will quit and all changes will be lost." );
     QMessageBox mb( QMessageBox::Question, title, question, QMessageBox::Yes | QMessageBox::No, m_widget );
     mb.setDefaultButton( QMessageBox::No );
-    mb.button( QMessageBox::Yes )->setText( tr( "&Yes" ) );
-    mb.button( QMessageBox::No )->setText( tr( "&No" ) );
+    Calamares::fixButtonLabels( &mb );
     int response = mb.exec();
     return response == QMessageBox::Yes;
 }
