@@ -9,9 +9,38 @@
 
 #include "PackageModel.h"
 
+#include "Branding.h"
 #include "utils/Logger.h"
 #include "utils/Variant.h"
 
+#include <QFileInfo>
+
+/** @brief A wrapper for CalamaresUtils::getSubMap that excludes the success param
+ */
+static QVariantMap
+getSubMap( const QVariantMap& map, const QString& key )
+{
+    bool success;
+
+    return CalamaresUtils::getSubMap( map, key, success );
+}
+
+static QPixmap
+loadScreenshot( const QString& path )
+{
+    if ( QFileInfo::exists( path ) )
+    {
+        return QPixmap( path );
+    }
+
+    const auto* branding = Calamares::Branding::instance();
+    if ( !branding )
+    {
+        return QPixmap();
+    }
+    return QPixmap( branding->componentDirectory() + QStringLiteral( "/" ) + path );
+}
+
 PackageItem::PackageItem() {}
 
 PackageItem::PackageItem( const QString& a_id, const QString& a_name, const QString& a_description )
@@ -32,12 +61,13 @@ PackageItem::PackageItem( const QString& a_id,
 {
 }
 
-PackageItem::PackageItem::PackageItem( const QVariantMap& item_map )
+PackageItem::PackageItem( const QVariantMap& item_map )
     : id( CalamaresUtils::getString( item_map, "id" ) )
     , name( CalamaresUtils::Locale::TranslatedString( item_map, "name" ) )
     , description( CalamaresUtils::Locale::TranslatedString( item_map, "description" ) )
-    , screenshot( CalamaresUtils::getString( item_map, "screenshot" ) )
+    , screenshot( loadScreenshot( CalamaresUtils::getString( item_map, "screenshot" ) ) )
     , packageNames( CalamaresUtils::getStringList( item_map, "packages" ) )
+    , netinstallData( getSubMap( item_map, "netinstall" ) )
 {
     if ( name.isEmpty() && id.isEmpty() )
     {
@@ -106,6 +136,25 @@ PackageListModel::getInstallPackagesForNames( const QStringList& ids ) const
     return l;
 }
 
+QVariantList
+PackageListModel::getNetinstallDataForNames( const QStringList& ids ) const
+{
+    QVariantList l;
+    for ( auto& p : m_packages )
+    {
+        if ( ids.contains( p.id ) )
+        {
+            if ( !p.netinstallData.isEmpty() )
+            {
+                QVariantMap newData = p.netinstallData;
+                newData[ "source" ] = QStringLiteral( "packageChooser" );
+                l.append( newData );
+            }
+        }
+    }
+    return l;
+}
+
 int
 PackageListModel::rowCount( const QModelIndex& index ) const
 {
