@@ -26,6 +26,7 @@ struct PackageItem
     CalamaresUtils::Locale::TranslatedString description;
     QPixmap screenshot;
     QStringList packageNames;
+    QVariantMap netinstallData;
 
     /// @brief Create blank PackageItem
     PackageItem();
@@ -111,6 +112,14 @@ public:
      */
     QStringList getInstallPackagesForNames( const QStringList& ids ) const;
 
+    /** @brief Does a name lookup (based on id) and returns the netinstall data
+     *
+     * If there is a package with an id in @p ids, returns their netinstall data
+     *
+     * returns a list of netinstall data or an emply list if none is found
+     */
+    QVariantList getNetinstallDataForNames( const QStringList& ids ) const;
+
     enum Roles : int
     {
         NameRole = Qt::DisplayRole,
