@@ -11,6 +11,7 @@
 #include "DeviceList.h"
 
 #include "partition/PartitionIterator.h"
+#include "utils/CalamaresUtilsSystem.h"
 #include "utils/Logger.h"
 
 #include <kpmcore/backend/corebackend.h>
@@ -40,16 +41,30 @@ hasRootPartition( Device* device )
     return false;
 }
 
+/** @brief Check if @p path holds an iso9660 filesystem
+ *
+ * The @p path should point to a device; blkid is used to check the FS type.
+ */
 static bool
 blkIdCheckIso9660( const QString& path )
 {
-    QProcess blkid;
-    blkid.start( "blkid", { path } );
-    blkid.waitForFinished();
-    QString output = QString::fromLocal8Bit( blkid.readAllStandardOutput() );
-    return output.contains( "iso9660" );
+    // If blkid fails, there's no output, but we don't care
+    auto r = CalamaresUtils::System::runCommand( { "blkid", path }, std::chrono::seconds( 30 ) );
+    return r.getOutput().contains( "iso9660" );
 }
 
+/// @brief Convenience to check if @p partition holds an iso9660 filesystem
+static bool
+blkIdCheckIso9660P( const Partition* partition )
+{
+    return blkIdCheckIso9660( partition->partitionPath() );
+}
+
+/** @brief Check if the @p device is an iso9660 device
+ *
+ * An iso9660 device is **probably** a CD-ROM. If the device holds an
+ * iso9660 FS, or any of its partitions do, then we call it an iso9660 device.
+ */
 static bool
 isIso9660( const Device* device )
 {
@@ -65,13 +80,8 @@ isIso9660( const Device* device )
 
     if ( device->partitionTable() && !device->partitionTable()->children().isEmpty() )
     {
-        for ( const Partition* partition : device->partitionTable()->children() )
-        {
-            if ( blkIdCheckIso9660( partition->partitionPath() ) )
-            {
-                return true;
-            }
-        }
+        const auto& p = device->partitionTable()->children();
+        return std::any_of( p.cbegin(), p.cend(), blkIdCheckIso9660P );
     }
     return false;
 }
@@ -112,6 +122,11 @@ QList< Device* >
 getDevices( DeviceType which )
 {
     CoreBackend* backend = CoreBackendManager::self()->backend();
+    if ( !backend )
+    {
+        cWarning() << "No KPM backend found.";
+        return {};
+    }
 #if defined( WITH_KPMCORE4API )
     DeviceList devices = backend->scanDevices( /* not includeReadOnly, not includeLoopback */ ScanFlag( 0 ) );
 #else
@@ -128,7 +143,7 @@ getDevices( DeviceType which )
      */
 #ifdef DEBUG_PARTITION_UNSAFE
     cWarning() << "Allowing unsafe partitioning choices." << devices.count() << "candidates.";
-#ifdef DEBUG_PARTITION_LAME
+#ifdef DEBUG_PARTITION_BAIL_OUT
     cDebug() << Logger::SubEntry << "unsafe partitioning has been lamed, and will fail.";
 #endif
 
