@@ -43,6 +43,25 @@ class PartitionRole;
 namespace KPMHelpers
 {
 
+/** @brief Return (errors) for savePassphrase()
+ *
+ * There's a handful of things that can go wrong when
+ * saving a passphrase for a given partition; this
+ * expresses clearly which ones are wrong.
+ *
+ * @c NoError is "Ok" when saving the passphrase succeeds.
+ */
+enum class SavePassphraseValue
+{
+    NoError,
+    EmptyPassphrase,
+    NotLuksPartition,
+    IncorrectPassphrase,
+    CryptsetupError,
+    NoMapperNode,
+    DeviceNotDecrypted
+};
+
 /**
  * Iterates on all devices and return the first partition which is associated
  * with mountPoint. This uses PartitionInfo::mountPoint(), not Partition::mountPoint()
@@ -74,7 +93,15 @@ Partition* createNewEncryptedPartition( PartitionNode* parent,
 
 Partition* clonePartition( Device* device, Partition* partition );
 
-int updateLuksDevice( Partition* partition, const QString& passphrase );
+/** @brief Save an existing passphrase for a previously encrypted partition.
+ *
+ * Tries to apply the passphrase to the partition; this checks if the
+ * @p partition is one that can have a passphrase applied, and
+ * runs `cryptsetup` to check that the passphrase actually works
+ * for the partition. Returns `NoError` on success, or an explanatory
+ * other value if it fails.
+ */
+SavePassphraseValue savePassphrase( Partition* partition, const QString& passphrase );
 
 /** @brief Return a result for an @p operation
  *
