@@ -12,6 +12,7 @@
 
 #include "core/ColorUtils.h"
 #include "core/PartitionModel.h"
+#include "core/SizeUtils.h"
 
 #include "utils/CalamaresUtilsGui.h"
 #include "utils/Logger.h"
@@ -20,8 +21,6 @@
 #include <kpmcore/core/device.h>
 #include <kpmcore/fs/filesystem.h>
 
-#include <KFormat>
-
 // Qt
 #include <QGuiApplication>
 #include <QMouseEvent>
@@ -39,7 +38,7 @@ static QStringList
 buildUnknownDisklabelTexts( Device* dev )
 {
     QStringList texts = { QObject::tr( "Unpartitioned space or unknown partition table" ),
-                          KFormat().formatByteSize( dev->totalLogical() * dev->logicalSize() ) };
+                          formatByteSize( dev->totalLogical() * dev->logicalSize() ) };
     return texts;
 }
 
@@ -520,7 +519,7 @@ void
 PartitionLabelsView::setSelectionModel( QItemSelectionModel* selectionModel )
 {
     QAbstractItemView::setSelectionModel( selectionModel );
-    connect( selectionModel, &QItemSelectionModel::selectionChanged, this, [=] { viewport()->repaint(); } );
+    connect( selectionModel, &QItemSelectionModel::selectionChanged, this, [ = ] { viewport()->repaint(); } );
 }
 
 
