@@ -11,7 +11,10 @@
 
 #include "DeletePartitionJob.h"
 
-// KPMcore
+#include "core/KPMHelpers.h"
+
+#include "utils/CalamaresUtilsSystem.h"
+
 #include <kpmcore/core/device.h>
 #include <kpmcore/core/partition.h>
 #include <kpmcore/core/partitiontable.h>
@@ -19,6 +22,45 @@
 #include <kpmcore/ops/deleteoperation.h>
 #include <kpmcore/util/report.h>
 
+#include <QCoreApplication>
+
+/** @brief Determine if the given partition is of type Zfs
+ *
+ * Returns true if @p partition is of type Zfs
+ *
+ */
+static bool
+isZfs( Partition* partition )
+{
+    return partition->fileSystem().type() == FileSystem::Type::Zfs;
+}
+
+/** @brief Remove the given partition manually
+ *
+ * Uses sfdisk to remove @p partition.  This should only be used in cases
+ * where using kpmcore to remove the partition would not be appropriate
+ *
+ */
+static Calamares::JobResult
+removePartition( Partition* partition )
+{
+    auto r = CalamaresUtils::System::instance()->runCommand(
+        { "sfdisk", "--delete", "--force", partition->devicePath(), QString::number( partition->number() ) },
+        std::chrono::seconds( 5 ) );
+    if ( r.getExitCode() != 0 || r.getOutput().contains( "failed" ) )
+    {
+        return Calamares::JobResult::error(
+            QCoreApplication::translate( DeletePartitionJob::staticMetaObject.className(), "Deletion Failed" ),
+            QCoreApplication::translate( DeletePartitionJob::staticMetaObject.className(),
+                                         "Failed to delete the partition with output: " )
+                + r.getOutput() );
+    }
+    else
+    {
+        return Calamares::JobResult::ok();
+    }
+}
+
 DeletePartitionJob::DeletePartitionJob( Device* device, Partition* partition )
     : PartitionJob( partition )
     , m_device( device )
@@ -49,17 +91,15 @@ DeletePartitionJob::prettyStatusMessage() const
 Calamares::JobResult
 DeletePartitionJob::exec()
 {
-    Report report( nullptr );
-    DeleteOperation op( *m_device, m_partition );
-    op.setStatus( Operation::StatusRunning );
-
-    QString message = tr( "The installer failed to delete partition %1." ).arg( m_partition->devicePath() );
-    if ( op.execute( report ) )
+    // The current implementation of remove() for zfs in kpmcore trys to destroy the zpool by label
+    // This isn't what we want here so we delete the partition instead.
+    if ( isZfs( m_partition ) )
     {
-        return Calamares::JobResult::ok();
+        return removePartition( m_partition );
     }
 
-    return Calamares::JobResult::error( message, report.toText() );
+    return KPMHelpers::execute( DeleteOperation( *m_device, m_partition ),
+                                tr( "The installer failed to delete partition %1." ).arg( m_partition->devicePath() ) );
 }
 
 void
