@@ -10,14 +10,16 @@
 #ifndef CLEARMOUNTSJOBTESTS_H
 #define CLEARMOUNTSJOBTESTS_H
 
+#include "partition/KPMHelper.h"
+
 #include <QObject>
-#include <core/device.h>
 
 class CreateLayoutsTests : public QObject
 {
     Q_OBJECT
 public:
     CreateLayoutsTests();
+    ~CreateLayoutsTests() override = default;
 
 private Q_SLOTS:
     void testFixedSizePartition();
@@ -31,6 +33,7 @@ class TestDevice : public Device
 {
 public:
     TestDevice( const QString& name, const qint64 logicalSectorSize, const qint64 totalLogicalSectors );
+    ~TestDevice() override;
 };
 
 #endif
