@@ -19,11 +19,75 @@
 
 #include <KMacroExpander>
 
-#include <QSemaphore>
-#include <QTimer>
+#include <QCoreApplication>
 
 #include <chrono>
 
+
+// Namespace keeps all the actual jobs anonymous, the
+// public API is the addJob() functions below the namespace.
+namespace
+{
+
+/** @brief Install-tracking job (gets a URL)
+ *
+ * The install-tracking job (there is only one kind) does a GET
+ * on a configured URL with some additional information about
+ * the machine (if configured into the URL).
+ *
+ * No persistent tracking is done.
+ */
+class TrackingInstallJob : public Calamares::Job
+{
+public:
+    TrackingInstallJob( const QString& url );
+    ~TrackingInstallJob() override;
+
+    QString prettyName() const override;
+    QString prettyStatusMessage() const override;
+    Calamares::JobResult exec() override;
+
+private:
+    const QString m_url;
+};
+
+/** @brief Tracking machines, update-manager style
+ *
+ * The machine has a machine-id, and this is sed(1)'ed into the
+ * update-manager configuration, to report the machine-id back
+ * to distro servers.
+ */
+class TrackingMachineUpdateManagerJob : public Calamares::Job
+{
+public:
+    ~TrackingMachineUpdateManagerJob() override;
+
+    QString prettyName() const override;
+    QString prettyStatusMessage() const override;
+    Calamares::JobResult exec() override;
+};
+
+/** @brief Turn on KUserFeedback in target system
+ *
+ * This writes suitable files for turning on KUserFeedback for the
+ * normal user configured in Calamares. The feedback can be reconfigured
+ * by the user through Plasma's user-feedback dialog.
+ */
+class TrackingKUserFeedbackJob : public Calamares::Job
+{
+public:
+    TrackingKUserFeedbackJob( const QString& username, const QStringList& areas );
+    ~TrackingKUserFeedbackJob() override;
+
+    QString prettyName() const override;
+    QString prettyStatusMessage() const override;
+    Calamares::JobResult exec() override;
+
+private:
+    QString m_username;
+    QStringList m_areas;
+};
+
 TrackingInstallJob::TrackingInstallJob( const QString& url )
     : m_url( url )
 {
@@ -34,13 +98,13 @@ TrackingInstallJob::~TrackingInstallJob() {}
 QString
 TrackingInstallJob::prettyName() const
 {
-    return tr( "Installation feedback" );
+    return QCoreApplication::translate( "TrackingInstallJob", "Installation feedback" );
 }
 
 QString
 TrackingInstallJob::prettyStatusMessage() const
 {
-    return tr( "Sending installation feedback." );
+    return QCoreApplication::translate( "TrackingInstallJob", "Sending installation feedback." );
 }
 
 Calamares::JobResult
@@ -57,8 +121,9 @@ TrackingInstallJob::exec()
     if ( result.status == RequestStatus::Timeout )
     {
         cWarning() << "install-tracking request timed out.";
-        return Calamares::JobResult::error( tr( "Internal error in install-tracking." ),
-                                            tr( "HTTP request timed out." ) );
+        return Calamares::JobResult::error(
+            QCoreApplication::translate( "TrackingInstallJob", "Internal error in install-tracking." ),
+            QCoreApplication::translate( "TrackingInstallJob", "HTTP request timed out." ) );
     }
     return Calamares::JobResult::ok();
 }
@@ -68,13 +133,13 @@ TrackingMachineUpdateManagerJob::~TrackingMachineUpdateManagerJob() {}
 QString
 TrackingMachineUpdateManagerJob::prettyName() const
 {
-    return tr( "Machine feedback" );
+    return QCoreApplication::translate( "TrackingMachineUpdateManagerJob", "Machine feedback" );
 }
 
 QString
 TrackingMachineUpdateManagerJob::prettyStatusMessage() const
 {
-    return tr( "Configuring machine feedback." );
+    return QCoreApplication::translate( "TrackingMachineUpdateManagerJob", "Configuring machine feedback." );
 }
 
 Calamares::JobResult
@@ -97,14 +162,20 @@ TrackingMachineUpdateManagerJob::exec()
     else if ( r > 0 )
     {
         return Calamares::JobResult::error(
-            tr( "Error in machine feedback configuration." ),
-            tr( "Could not configure machine feedback correctly, script error %1." ).arg( r ) );
+            QCoreApplication::translate( "TrackingMachineUpdateManagerJob",
+                                         "Error in machine feedback configuration." ),
+            QCoreApplication::translate( "TrackingMachineUpdateManagerJob",
+                                         "Could not configure machine feedback correctly, script error %1." )
+                .arg( r ) );
     }
     else
     {
         return Calamares::JobResult::error(
-            tr( "Error in machine feedback configuration." ),
-            tr( "Could not configure machine feedback correctly, Calamares error %1." ).arg( r ) );
+            QCoreApplication::translate( "TrackingMachineUpdateManagerJob",
+                                         "Error in machine feedback configuration." ),
+            QCoreApplication::translate( "TrackingMachineUpdateManagerJob",
+                                         "Could not configure machine feedback correctly, Calamares error %1." )
+                .arg( r ) );
     }
 }
 
@@ -119,13 +190,13 @@ TrackingKUserFeedbackJob::~TrackingKUserFeedbackJob() {}
 QString
 TrackingKUserFeedbackJob::prettyName() const
 {
-    return tr( "KDE user feedback" );
+    return QCoreApplication::translate( "TrackingKUserFeedbackJob", "KDE user feedback" );
 }
 
 QString
 TrackingKUserFeedbackJob::prettyStatusMessage() const
 {
-    return tr( "Configuring KDE user feedback." );
+    return QCoreApplication::translate( "TrackingKUserFeedbackJob", "Configuring KDE user feedback." );
 }
 
 Calamares::JobResult
@@ -147,20 +218,26 @@ FeedbackLevel=16
         if ( r > 0 )
         {
             return Calamares::JobResult::error(
-                tr( "Error in KDE user feedback configuration." ),
-                tr( "Could not configure KDE user feedback correctly, script error %1." ).arg( r ) );
+                QCoreApplication::translate( "TrackingKUserFeedbackJob", "Error in KDE user feedback configuration." ),
+                QCoreApplication::translate( "TrackingKUserFeedbackJob",
+                                             "Could not configure KDE user feedback correctly, script error %1." )
+                    .arg( r ) );
         }
         else if ( r < 0 )
         {
             return Calamares::JobResult::error(
-                tr( "Error in KDE user feedback configuration." ),
-                tr( "Could not configure KDE user feedback correctly, Calamares error %1." ).arg( r ) );
+                QCoreApplication::translate( "TrackingKUserFeedbackJob", "Error in KDE user feedback configuration." ),
+                QCoreApplication::translate( "TrackingKUserFeedbackJob",
+                                             "Could not configure KDE user feedback correctly, Calamares error %1." )
+                    .arg( r ) );
         }
     }
 
     return Calamares::JobResult::ok();
 }
 
+}  // namespace
+
 void
 addJob( Calamares::JobList& list, InstallTrackingConfig* config )
 {
