@@ -49,7 +49,7 @@ DEFINE_CHECK_FUNC( minLength )
     {
         cDebug() << Logger::SubEntry << "minLength set to" << minLength;
         checks.push_back( PasswordCheck( []() { return QCoreApplication::translate( "PWQ", "Password is too short" ); },
-                                         [minLength]( const QString& s ) { return s.length() >= minLength; },
+                                         [ minLength ]( const QString& s ) { return s.length() >= minLength; },
                                          PasswordCheck::Weight( 10 ) ) );
     }
 }
@@ -65,7 +65,7 @@ DEFINE_CHECK_FUNC( maxLength )
     {
         cDebug() << Logger::SubEntry << "maxLength set to" << maxLength;
         checks.push_back( PasswordCheck( []() { return QCoreApplication::translate( "PWQ", "Password is too long" ); },
-                                         [maxLength]( const QString& s ) { return s.length() <= maxLength; },
+                                         [ maxLength ]( const QString& s ) { return s.length() <= maxLength; },
                                          PasswordCheck::Weight( 10 ) ) );
     }
 }
@@ -378,8 +378,9 @@ DEFINE_CHECK_FUNC( libpwquality )
     /* Something actually added? */
     if ( requirement_count )
     {
-        checks.push_back( PasswordCheck( [settings]() { return settings->explanation(); },
-                                         [settings]( const QString& s ) {
+        checks.push_back( PasswordCheck( [ settings ]() { return settings->explanation(); },
+                                         [ settings ]( const QString& s )
+                                         {
                                              int r = settings->check( s );
                                              if ( r < 0 )
                                              {
