@@ -22,8 +22,9 @@
 #include <QFile>
 #include <QFileInfo>
 
-SetupSudoJob::SetupSudoJob( const QString& group )
+SetupSudoJob::SetupSudoJob( const QString& group, Config::SudoStyle style )
     : m_sudoGroup( group )
+    , m_sudoStyle( style )
 {
 }
 
@@ -33,6 +34,19 @@ SetupSudoJob::prettyName() const
     return tr( "Configure <pre>sudo</pre> users." );
 }
 
+static QString
+designatorForStyle( Config::SudoStyle style )
+{
+    switch ( style )
+    {
+    case Config::SudoStyle::UserOnly:
+        return QStringLiteral( "(ALL)" );
+    case Config::SudoStyle::UserAndGroup:
+        return QStringLiteral( "(ALL:ALL)" );
+    }
+    __builtin_unreachable();
+}
+
 Calamares::JobResult
 SetupSudoJob::exec()
 {
@@ -42,7 +56,9 @@ SetupSudoJob::exec()
         return Calamares::JobResult::ok();
     }
 
-    QString sudoersLine = QString( "%%1 ALL=(ALL) ALL\n" ).arg( m_sudoGroup );
+    // One % for the sudo format, keep it outside of the string to avoid accidental replacement
+    QString sudoersLine
+        = QChar( '%' ) + QString( "%1 ALL=%2 ALL\n" ).arg( m_sudoGroup, designatorForStyle( m_sudoStyle ) );
     auto fileResult
         = CalamaresUtils::System::instance()->createTargetFile( QStringLiteral( "/etc/sudoers.d/10-installer" ),
                                                                 sudoersLine.toUtf8().constData(),
